@@ -1,60 +1,87 @@
 import logging
+from pathlib import Path
 
 from django.core.files.storage import get_storage_class
-from django.core.management.base import BaseCommand
+from django.core.management.base import BaseCommand, CommandError
 
 try:
     from django.test.runner import get_max_test_processes
 except ImportError:
     # Django<4
     def get_max_test_processes():
-        raise Exception(
+        raise CommandError(
             "Django<4 do not implement get_max_test_processes."
             " Use --parallel $(nproc) to not depend on this."
         )
 
 
 from django_migrations_ci import django
+from django_migrations_ci.conf import settings
 
 logger = logging.getLogger(__name__)
 
 
 class Command(BaseCommand):
     def add_arguments(self, parser):
-        parser.add_argument("-n", "--parallel", default=None)
+        parser.add_argument("-n", "--parallel", default=settings.parallel)
         parser.add_argument(
             "--pytest",
             dest="is_pytest",
             action="store_true",
-            default=False,
+            default=settings.is_pytest,
         )
-        parser.add_argument("--directory", default="")
         parser.add_argument(
-            "--storage-class",
-            default="django.core.files.storage.FileSystemStorage",
+            "--directory",
+            dest="location",
+            default=settings.location,
+            help="Deprecated, use --location instead.",
+        )
+        parser.add_argument("--location", default=settings.location)
+        parser.add_argument(
+            "--storage",
+            dest="storage_class",
+            default=settings.storage_class,
             type=get_storage_class,
         )
-        parser.add_argument("--depth", type=int, default=0)
+        parser.add_argument("--depth", type=int, default=settings.depth)
+
+    def _setup_logging(self):
+        lib_logger = logging.getLogger("django_migrations_ci")
+        lib_logger.setLevel(logging.INFO)
+        lib_logger.addHandler(logging.StreamHandler())
 
     def handle(
         self,
         *args,
         parallel,
         is_pytest,
-        directory,
+        location,
         storage_class,
         depth,
         verbosity,
         **options,
     ):
+        self._setup_logging()
+
         if parallel == "auto":
             parallel = get_max_test_processes()
         elif parallel is not None:
             parallel = int(parallel)
 
+        if location:
+            location = str(Path(location).expanduser())
+        else:
+            default_storage_class = get_storage_class(
+                "django.core.files.storage.FileSystemStorage"
+            )
+            if issubclass(storage_class, default_storage_class):
+                location_path = Path("~/.migrateci").expanduser()
+                location_path.mkdir(parents=True, exist_ok=True)
+                location = str(location_path)
+
         if verbosity >= 2:
-            logger.info(f"Using storage {storage_class=} on {directory=}.")
-        storage = storage_class(location=directory)
+            logger.info(f"Using storage {storage_class=} on {location=}.")
+        storage = storage_class(location=location)
 
         _, files = storage.listdir("")
         files = set(files)
@@ -101,12 +128,12 @@ class Command(BaseCommand):
 
         if cached_files:
             if verbosity >= 2:
-                logger.info("Create test db from cache.")
+                logger.info(f"Create test db from cache {cached_checksum=}.")
             django.create_test_db(verbosity=verbosity)
             for connection in unique_connections:
                 cached_file = cached_files[connection.alias]
                 with django.test_db(connection):
-                    django.load(connection, cached_file, storage)
+                    django.load(connection, cached_file, storage, verbosity=verbosity)
 
         if current_checksum != cached_checksum:
             if verbosity >= 2:
@@ -118,7 +145,7 @@ class Command(BaseCommand):
             for connection in unique_connections:
                 current_file = f"migrateci-{connection.alias}-{current_checksum}"
                 with django.test_db(connection):
-                    django.dump(connection, current_file, storage)
+                    django.dump(connection, current_file, storage, verbosity=verbosity)
 
         if parallel:
             if verbosity >= 2:
